@@ -8,10 +8,10 @@ test_that("datetimes are converted to e.g. 2013-01-02 05:00:00", {
   df <- rbind(data.frame(who = "me", time.obj, dollars = c(1.1, 5.6)),
               data.frame(who = "you", time.obj, dollars = c(10.2, 0)))
   gg <- qplot(time.obj, dollars, data = df, color = who, geom = "line")
-  info <- save_outputs(gg, "date-strings")
-  expect_equal(length(info$data), 2)
+  info <- expect_doppelganger_built(gg, "date-strings")
+  expect_equivalent(length(info$data), 2)
   for(trace in info$data[1:2]){
-    expect_equal(as.numeric(time.obj), trace$x)
+    expect_equivalent(as.numeric(time.obj), trace$x)
   }
 })
 
@@ -22,8 +22,8 @@ test_that("class Date is supported", {
   )
   df$x <- as.Date(df$x)
   gg <- ggplot(df) + geom_line(aes(x = x, y = y))
-  info <- save_outputs(gg, "date-class-Date")
-  expect_equal(length(info$data), 1)
+  info <- expect_doppelganger_built(gg, "date-class-Date")
+  expect_equivalent(length(info$data), 1)
 })
 
 test_that("scale_x_date and irregular time series work", {
@@ -33,5 +33,7 @@ test_that("scale_x_date and irregular time series work", {
   )
   df <- df[order(df$date), ]
   dt <- qplot(date, price, data = df, geom = "line") + theme(aspect.ratio = 1/4)
-  info <- save_outputs(dt, "date-irregular-time-series")
+  
+  info <- expect_warning(expect_doppelganger_built(dt, "date-irregular-time-series"), 
+                         regexp = "Aspect ratios aren't yet implemented")
 })
