@@ -56,7 +56,8 @@ test_that('boxes with coord_flip()+facet_grid(scales="free")', {
 
 test_that("limits can hide data", {
   boxes.limits <- boxes + scale_x_discrete(limits = c("trt1", "ctrl"))
-  info <- expect_traces(boxes.limits, 1, "limits-hide")
+  info <- expect_warning(expect_traces(boxes.limits, 1, "limits-hide"), 
+                         regexp = "missing values")
   expect_equivalent(info$layout$xaxis$ticktext, c("trt1", "ctrl"))
 })
 
@@ -190,4 +191,13 @@ test_that("R line breaks are translated to HTML line breaks", {
   )
 })
 
-
+test_that("Missing axis ticks are treated correctly", {
+  # https://github.com/ropensci/plotly/issues/1721
+  p <- ggplot(data = mtcars, aes(x = qsec, y = disp)) + 
+    geom_point() + 
+    scale_x_continuous(
+      breaks = pretty(range(mtcars$qsec), n = 10),
+      labels = pretty(range(mtcars$qsec), n = 10)
+    )
+  expect_doppelganger_built(p, "continuous-x-missing")
+})
